@@ -287,7 +287,6 @@ p_dict[np.mod] = _d_check_uniform
 p_dict[np.fmod] = _d_check_uniform
 p_dict[np.remainder] = _d_check_uniform
 p_dict[np.floor_divide] = _d_check_uniform
-p_dict[np.arctan2] = _d_check_uniform
 p_dict[np.hypot] = _d_check_uniform
 p_dict[np.equal] = _d_check_uniform
 p_dict[np.not_equal] = _d_check_uniform
@@ -296,6 +295,18 @@ p_dict[np.less_equal] = _d_check_uniform
 p_dict[np.greater] = _d_check_uniform
 p_dict[np.greater_equal] = _d_check_uniform
 
+def _d_arctan2(q1, q2, out=None):
+    try:
+        assert q1._dimensionality == q2._dimensionality
+        return Dimensionality()
+    except AssertionError:
+        raise ValueError(
+            'quantities must have identical units, got "%s" and "%s"' %
+            (q1.units, q2.units)
+        )
+
+p_dict[np.arctan2] = _d_arctan2
+
 def _d_power(q1, q2, out=None):
     if getattr(q2, 'dimensionality', None):
         raise ValueError("exponent must be dimensionless")
@@ -329,6 +340,13 @@ p_dict[np.floor] = _d_copy
 p_dict[np.fix] = _d_copy
 p_dict[np.ceil] = _d_copy
 
+def _d_clip(a1, a2, a3, q):
+    return q.dimensionality
+try:
+    p_dict[np.core.umath.clip] = _d_clip
+except AttributeError:
+    pass # For compatibility with Numpy < 1.17 when clip wasn't a ufunc yet
+
 def _d_sqrt(q1, out=None):
     return q1._dimensionality**0.5
 p_dict[np.sqrt] = _d_sqrt
